@@ -1,17 +1,20 @@
 acf2 <-
-function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, na.action = na.pass, ...){
-  acf  = stats::acf
-  pacf = stats::pacf
-  num  = length(series)
+function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, na.action=na.pass, ...){
+  acf       = stats::acf
+  pacf      = stats::pacf
   frequency = stats::frequency
-  if (num > 59 & is.null(max.lag))  max.lag = max(ceiling(10+sqrt(num)), 4*frequency(series)) 
+  num       = length(series)
+  xfreq     = frequency(series)
+
+  if (num > 59 & is.null(max.lag))  max.lag = max(ceiling(10+sqrt(num)), 4*xfreq) 
   if (num < 60 & is.null(max.lag))  max.lag = floor(5*log10(num+5))
-  if (max.lag > (num-1)) stop("Number of lags exceeds number of observations")
-  if (is.null(main)) {main = paste("Series: ",deparse(substitute(series)))}
+  if (max.lag > (num-2)) stop("Number of lags exceeds number of observations")
+  if (is.null(main)) main = paste("Series: ",deparse(substitute(series)))
+
   ACF  = acf(series, max.lag, plot=FALSE, na.action = na.action,...)$acf[-1]
   PACF = pacf(series, max.lag, plot=FALSE, na.action = na.action, ...)$acf
-  frequency = frequency(series)
-  LAG  = (1:max.lag)/frequency
+  LAG  = (1:max.lag)/xfreq
+
  if(plot){
    abline = graphics::abline
    par = graphics::par
@@ -28,7 +31,7 @@ function(series, max.lag=NULL, plot=TRUE, main=NULL, ylim=NULL, na.action = na.p
     ylim = c(minu,maxu)
    }
   par(mfrow=c(2,1), cex.main=1) 
-   Xlab = ifelse(frequency>1, paste('LAG', expression('\u00F7'), frequency), 'LAG')
+   Xlab = ifelse(xfreq>1, paste('LAG \u00F7', xfreq), 'LAG')
    tsplot(LAG, ACF, ylim=ylim, main=main, xlab=Xlab, ylab='ACF', type='h', ...)
     abline(h=c(0,L,U), lty=c(1,2,2), col=c(8,4,4))
    tsplot(LAG, PACF, ylim=ylim, main=NULL, xlab=Xlab, ylab='PACF', type='h', ...)
