@@ -13,6 +13,7 @@ function(ar=0, ma=0, var.noise=1, n.freq=500,  main='from specified model',
      if(any(abs(z.ma) <= 1)) {cat("WARNING: Model Not Invertible", "\n"); check <- check + 1}
      if (check > 0) stop("Try Again")
     #
+     xfreq    <- frequency
      ar.order <- length(ar)
      ma.order <- length(ma)
     # check (near) parameter redundancy [i.e. are any roots (approximately) equal]  
@@ -28,14 +29,14 @@ function(ar=0, ma=0, var.noise=1, n.freq=500,  main='from specified model',
       sn.ma <- outer(freq, 1:ma.order, function(x, y) sin(2 * pi * x * y)) %*% -ma                      
     spec <- var.noise*((1 - cs.ma)^2 + sn.ma^2)/((1 - cs.ar)^2 + sn.ar^2)
     
-    spg.out <- list(freq=freq*frequency, spec=spec)
+    spg.out <- list(freq=freq*xfreq, spec=spec)
     Ylab = 'spectrum'
-    Xlab = ifelse(frequency>1, paste('frequency', expression('\u00D7'), frequency), 'frequency')
+    Xlab = ifelse(xfreq>1, paste('frequency \u00D7', xfreq), 'frequency')
      m1  = min(spec) 
      m2  = max(spec) 
      yspread =  (m2 - m1)/var.noise 
      if (is.null(ylim) & yspread < 1) ylim = c(max(m1-2*var.noise, 0.1*var.noise), m2+2*var.noise)
-   tsplot(freq*frequency, spec, xlab=Xlab, ylab=Ylab, main=main, ylim=ylim, ...)
+   tsplot(freq*xfreq, spec, xlab=Xlab, ylab=Ylab, main=main, ylim=ylim, ...)
    return(invisible(spg.out))
 }
 
