@@ -7,6 +7,6 @@ function(series, order=1, lowess=FALSE, lowspan=2/3){
     } else {
       y = as.vector(time(series))
       u = stats::lm(series~ poly(y, order), na.action=NULL)
-      return(round(resid(u),4))
+      return(resid(u))
     }
  }
