@@ -7,16 +7,17 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
   topper = ifelse(is.null(main), 0, .5) 
   type0  = 'n' 
   type1  = ifelse(is.null(type), 'l', type)
-  pch    =  rep(pch, ceiling(nser/length(pch)))
-  lty    =  rep(lty, ceiling(nser/length(lty)))
-  lwd    =  rep(lwd, ceiling(nser/length(lwd)))
+  pch    = rep(pch, ceiling(nser/length(pch)))
+  lty    = rep(lty, ceiling(nser/length(lty)))
+  lwd    = rep(lwd, ceiling(nser/length(lwd)))
   
  if(!spaghetti || nser < 2){ # no spaghetti 
  if(!gg){                    # no gris-gris
   if (nser == 1) {           # single series
    if(is.null(ylab)) {ylab = ifelse(is.null(y), deparse(substitute(x)), 
                       deparse(substitute(y)))}
-   par(mar=c(2.5,2.5,1+topper,.5)+margins, mgp=c(1.6,.6,0)+mgpp, cex.main=1.2)
+   par(mar=c(2.5,2.5,1+topper,.5)+margins, mgp=c(1.6,.3,0)+mgpp, cex.main=1.2,
+              tcl=-.2, cex.axis=.9)
    plot(x, y, type = type0, axes=FALSE, ann=FALSE, main=NULL, ... )
    Grid(minor=minor, nxm=nxm, nym=nym, xm.grid=xm.grid, ym.grid=ym.grid)
    par(new=TRUE)
@@ -48,26 +49,26 @@ tsplot <- function(x, y = NULL, main=NULL, ylab=NULL, xlab='Time', type=NULL,
   if (nser == 1) {         # single series
    if(is.null(ylab)) {ylab = ifelse(is.null(y), deparse(substitute(x)), 
                       deparse(substitute(y)))}
-   par(mar=c(2.5,2.6,1+topper,.5)+margins, mgp=c(1.8,.6,0)+mgpp, cex.main=1.2,  
-              tcl=-.2, las=1, cex.axis=.9)    
+   par(mar=c(2.5,2.5,1+topper,.5)+margins, mgp=c(1.6,.3,0)+mgpp, cex.main=1.2,  
+              tcl=-.2, cex.axis=.8)    
    plot(x, y, type = type0, axes=FALSE, ann=FALSE, main=NULL, ... )
    brdr = par("usr")        
    rect(brdr[1], brdr[3], brdr[2], brdr[4], col=gray(.92), border='white')         
    Grid(minor=minor, nxm=nxm, nym=nym, xm.grid=xm.grid, ym.grid=ym.grid, col='white')
    par(new=TRUE)
    plot(x, y, type=type1, main=main, ylab=ylab, xlab=xlab, col=col, pch=pch, 
-         lty=lty, lwd=lwd, ... ) 
-   box(col=gray(1))
+         lty=lty, lwd=lwd, las=1, ... ) 
+   box(col='white', lwd=2)
   } else {                 # multiple series
    if(!is.null(ylab)){ ylab = rep(ylab, ceiling(nser/length(ylab))) } 
    prow = ceiling(nser/ncolm)
    culer = rep(col, nser)
    if(byrow){
    par(mfrow = c(prow, ncolm), cex.lab=1.1, oma = c(0,.25,3*topper,0)+margins, tcl=-.2, 
-       las=1, cex.axis=.9)
+         cex.axis=.9)
    } else {
    par(mfcol = c(prow, ncolm), cex.lab=1.1, oma = c(0,.25,3*topper,0)+margins, tcl=-.2, 
-        las=1, cex.axis=.9)
+         cex.axis=.9)
    }
    if (is.null(y) & is.null(ylab) ) { ylab=colnames(as.matrix(x))}
    if (!is.null(y) & is.null(ylab) )  { ylab=colnames(as.matrix(y))} 
