@@ -1,7 +1,7 @@
-.onAttach <- function(libname, pkgname){ 
+.onLoad <- function(libname, pkgname){ 
 			 palette(c("black","#F6483C","#00BA38","#1874cd","#0D9AC0","#cd1874","#CD7118","gray62"))
 			 }
 			 
-.onDetach <- function(libpath){ 
+.onUnload <- function(libpath){ 
 			 palette("default")
 			 }	 
\ No newline at end of file
